@@ -1,5 +1,10 @@
 from aws_recommendations.ec2 import *
 from aws_recommendations.rds import *
+from aws_recommendations.cost_estimations import *
+from aws_recommendations.redshift import *
+from aws_recommendations.ebs import *
+from aws_recommendations.s3 import *
+from aws_recommendations.elb import *
 import logging
 
 logging.basicConfig(level=logging.INFO)
@@ -36,8 +41,23 @@ def get_recommendations(self) -> list:
     recommendations= []
     recommendations += delete_or_downsize_instance_recommendation(self)
     recommendations += purge_unattached_vol_recommendation(self)
-    recommendations += downsize_underutilized_rds_recommendation(self)
     recommendations += purge_8_weeks_older_snapshots(self)
+    recommendations += reserved_instance_lease_expiration(self)
+    recommendations += unassociated_elastic_ip_addresses(self)
+    recommendations += unused_ami(self)
+
+    recommendations += downsize_underutilized_rds_recommendation(self)
+    recommendations += rds_idle_db_instances(self)
+    recommendations += rds_general_purpose_ssd(self)
+
     recommendations += get_generic_suggestions(self)
+    recommendations += estimated_savings(self)
+    recommendations += under_utilized_redshift_cluster(self)
+
+    recommendations += idle_ebs_volumes(self)
+    recommendations += ebs_general_purpose_ssd(self)
+
+    recommendations += enable_s3_bucket_keys(self)
+    recommendations += idle_elastic_load_balancer(self)
 
     return recommendations
\ No newline at end of file
